agent

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 30, 2021 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Message_Type_name = map[int32]string{
	0:  "UNKNOWN",
	1:  "GET_INFORMATION",
	2:  "INFORMATION_RESULT",
	3:  "GET_STATUS_MODULES",
	4:  "STATUS_MODULES_RESULT",
	5:  "START_MODULES",
	6:  "STOP_MODULES",
	7:  "UPDATE_MODULES",
	8:  "UPDATE_CONFIG_MODULES",
	9:  "AUTHENTICATION_REQUEST",
	10: "AUTHENTICATION_RESPONSE",
}
var Message_Type_value = map[string]int32{
	"UNKNOWN":                 0,
	"GET_INFORMATION":         1,
	"INFORMATION_RESULT":      2,
	"GET_STATUS_MODULES":      3,
	"STATUS_MODULES_RESULT":   4,
	"START_MODULES":           5,
	"STOP_MODULES":            6,
	"UPDATE_MODULES":          7,
	"UPDATE_CONFIG_MODULES":   8,
	"AUTHENTICATION_REQUEST":  9,
	"AUTHENTICATION_RESPONSE": 10,
}
var ModuleStatus_Status_name = map[int32]string{
	0: "UNKNOWN",
	1: "LOADED",
	2: "RUNNING",
	3: "STOPPED",
	4: "FREED",
}
var ModuleStatus_Status_value = map[string]int32{
	"UNKNOWN": 0,
	"LOADED":  1,
	"RUNNING": 2,
	"STOPPED": 3,
	"FREED":   4,
}

Functions

This section is empty.

Types

type AuthenticationRequest

type AuthenticationRequest struct {
	Timestamp            *int64   `protobuf:"varint,1,req,name=timestamp" json:"timestamp,omitempty"`
	Atoken               *string  `protobuf:"bytes,2,req,name=atoken" json:"atoken,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

Struct of authentication request for handshake atoken means agent token which is last stored value on agent side

func (*AuthenticationRequest) Descriptor

func (*AuthenticationRequest) Descriptor() ([]byte, []int)

func (*AuthenticationRequest) GetAtoken

func (m *AuthenticationRequest) GetAtoken() string

func (*AuthenticationRequest) GetTimestamp

func (m *AuthenticationRequest) GetTimestamp() int64

func (*AuthenticationRequest) ProtoMessage

func (*AuthenticationRequest) ProtoMessage()

func (*AuthenticationRequest) Reset

func (m *AuthenticationRequest) Reset()

func (*AuthenticationRequest) String

func (m *AuthenticationRequest) String() string

func (*AuthenticationRequest) XXX_DiscardUnknown

func (m *AuthenticationRequest) XXX_DiscardUnknown()

func (*AuthenticationRequest) XXX_Marshal

func (m *AuthenticationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*AuthenticationRequest) XXX_Merge

func (m *AuthenticationRequest) XXX_Merge(src proto.Message)

func (*AuthenticationRequest) XXX_Size

func (m *AuthenticationRequest) XXX_Size() int

func (*AuthenticationRequest) XXX_Unmarshal

func (m *AuthenticationRequest) XXX_Unmarshal(b []byte) error

type AuthenticationResponse

type AuthenticationResponse struct {
	Atoken               *string  `protobuf:"bytes,1,req,name=atoken" json:"atoken,omitempty"`
	Stoken               *string  `protobuf:"bytes,2,req,name=stoken" json:"stoken,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

Struct of authentication request for handshake atoken means agent token which will use for send API function from server stoken means server token which will use for send API function from agent

func (*AuthenticationResponse) Descriptor

func (*AuthenticationResponse) Descriptor() ([]byte, []int)

func (*AuthenticationResponse) GetAtoken

func (m *AuthenticationResponse) GetAtoken() string

func (*AuthenticationResponse) GetStoken

func (m *AuthenticationResponse) GetStoken() string

func (*AuthenticationResponse) ProtoMessage

func (*AuthenticationResponse) ProtoMessage()

func (*AuthenticationResponse) Reset

func (m *AuthenticationResponse) Reset()

func (*AuthenticationResponse) String

func (m *AuthenticationResponse) String() string

func (*AuthenticationResponse) XXX_DiscardUnknown

func (m *AuthenticationResponse) XXX_DiscardUnknown()

func (*AuthenticationResponse) XXX_Marshal

func (m *AuthenticationResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*AuthenticationResponse) XXX_Merge

func (m *AuthenticationResponse) XXX_Merge(src proto.Message)

func (*AuthenticationResponse) XXX_Size

func (m *AuthenticationResponse) XXX_Size() int

func (*AuthenticationResponse) XXX_Unmarshal

func (m *AuthenticationResponse) XXX_Unmarshal(b []byte) error

type Config

type Config struct {
	AgentId              *string      `protobuf:"bytes,1,req,name=agent_id,json=agentId" json:"agent_id,omitempty"`
	Os                   []*Config_OS `protobuf:"bytes,2,rep,name=os" json:"os,omitempty"`
	Name                 *string      `protobuf:"bytes,3,req,name=name" json:"name,omitempty"`
	Version              *string      `protobuf:"bytes,4,req,name=version" json:"version,omitempty"`
	Events               []string     `protobuf:"bytes,5,rep,name=events" json:"events,omitempty"`
	LastUpdate           *string      `protobuf:"bytes,6,req,name=last_update,json=lastUpdate" json:"last_update,omitempty"`
	XXX_NoUnkeyedLiteral struct{}     `json:"-"`
	XXX_unrecognized     []byte       `json:"-"`
	XXX_sizecache        int32        `json:"-"`
}

Config is structure that contains information about module

func (*Config) Descriptor

func (*Config) Descriptor() ([]byte, []int)

func (*Config) GetAgentId

func (m *Config) GetAgentId() string

func (*Config) GetEvents

func (m *Config) GetEvents() []string

func (*Config) GetLastUpdate

func (m *Config) GetLastUpdate() string

func (*Config) GetName

func (m *Config) GetName() string

func (*Config) GetOs

func (m *Config) GetOs() []*Config_OS

func (*Config) GetVersion

func (m *Config) GetVersion() string

func (*Config) ProtoMessage

func (*Config) ProtoMessage()

func (*Config) Reset

func (m *Config) Reset()

func (*Config) String

func (m *Config) String() string

func (*Config) XXX_DiscardUnknown

func (m *Config) XXX_DiscardUnknown()

func (*Config) XXX_Marshal

func (m *Config) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Config) XXX_Merge

func (m *Config) XXX_Merge(src proto.Message)

func (*Config) XXX_Size

func (m *Config) XXX_Size() int

func (*Config) XXX_Unmarshal

func (m *Config) XXX_Unmarshal(b []byte) error

type ConfigItem

type ConfigItem struct {
	DefaultConfig        *string  `protobuf:"bytes,1,req,name=default_config,json=defaultConfig" json:"default_config,omitempty"`
	ConfigSchema         *string  `protobuf:"bytes,2,req,name=config_schema,json=configSchema" json:"config_schema,omitempty"`
	CurrentConfig        *string  `protobuf:"bytes,3,req,name=current_config,json=currentConfig" json:"current_config,omitempty"`
	EventDataSchema      *string  `protobuf:"bytes,4,req,name=event_data_schema,json=eventDataSchema" json:"event_data_schema,omitempty"`
	EventConfigSchema    *string  `protobuf:"bytes,5,req,name=event_config_schema,json=eventConfigSchema" json:"event_config_schema,omitempty"`
	DefaultEventConfig   *string  `protobuf:"bytes,6,req,name=default_event_config,json=defaultEventConfig" json:"default_event_config,omitempty"`
	CurrentEventConfig   *string  `protobuf:"bytes,7,req,name=current_event_config,json=currentEventConfig" json:"current_event_config,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

ConfigItem is structure that contains information about config module

func (*ConfigItem) Descriptor

func (*ConfigItem) Descriptor() ([]byte, []int)

func (*ConfigItem) GetConfigSchema

func (m *ConfigItem) GetConfigSchema() string

func (*ConfigItem) GetCurrentConfig

func (m *ConfigItem) GetCurrentConfig() string

func (*ConfigItem) GetCurrentEventConfig

func (m *ConfigItem) GetCurrentEventConfig() string

func (*ConfigItem) GetDefaultConfig

func (m *ConfigItem) GetDefaultConfig() string

func (*ConfigItem) GetDefaultEventConfig

func (m *ConfigItem) GetDefaultEventConfig() string

func (*ConfigItem) GetEventConfigSchema

func (m *ConfigItem) GetEventConfigSchema() string

func (*ConfigItem) GetEventDataSchema

func (m *ConfigItem) GetEventDataSchema() string

func (*ConfigItem) ProtoMessage

func (*ConfigItem) ProtoMessage()

func (*ConfigItem) Reset

func (m *ConfigItem) Reset()

func (*ConfigItem) String

func (m *ConfigItem) String() string

func (*ConfigItem) XXX_DiscardUnknown

func (m *ConfigItem) XXX_DiscardUnknown()

func (*ConfigItem) XXX_Marshal

func (m *ConfigItem) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ConfigItem) XXX_Merge

func (m *ConfigItem) XXX_Merge(src proto.Message)

func (*ConfigItem) XXX_Size

func (m *ConfigItem) XXX_Size() int

func (*ConfigItem) XXX_Unmarshal

func (m *ConfigItem) XXX_Unmarshal(b []byte) error

type Config_OS

type Config_OS struct {
	Type                 *string  `protobuf:"bytes,1,req,name=type" json:"type,omitempty"`
	Arch                 []string `protobuf:"bytes,2,rep,name=arch" json:"arch,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*Config_OS) Descriptor

func (*Config_OS) Descriptor() ([]byte, []int)

func (*Config_OS) GetArch

func (m *Config_OS) GetArch() []string

func (*Config_OS) GetType

func (m *Config_OS) GetType() string

func (*Config_OS) ProtoMessage

func (*Config_OS) ProtoMessage()

func (*Config_OS) Reset

func (m *Config_OS) Reset()

func (*Config_OS) String

func (m *Config_OS) String() string

func (*Config_OS) XXX_DiscardUnknown

func (m *Config_OS) XXX_DiscardUnknown()

func (*Config_OS) XXX_Marshal

func (m *Config_OS) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Config_OS) XXX_Merge

func (m *Config_OS) XXX_Merge(src proto.Message)

func (*Config_OS) XXX_Size

func (m *Config_OS) XXX_Size() int

func (*Config_OS) XXX_Unmarshal

func (m *Config_OS) XXX_Unmarshal(b []byte) error

type Information

type Information struct {
	Os                   *Information_OS   `protobuf:"bytes,1,req,name=os" json:"os,omitempty"`
	User                 *Information_User `protobuf:"bytes,2,req,name=user" json:"user,omitempty"`
	XXX_NoUnkeyedLiteral struct{}          `json:"-"`
	XXX_unrecognized     []byte            `json:"-"`
	XXX_sizecache        int32             `json:"-"`
}

Communication message for INFORMATION_RESULT command

func (*Information) Descriptor

func (*Information) Descriptor() ([]byte, []int)

func (*Information) GetOs

func (m *Information) GetOs() *Information_OS

func (*Information) GetUser

func (m *Information) GetUser() *Information_User

func (*Information) ProtoMessage

func (*Information) ProtoMessage()

func (*Information) Reset

func (m *Information) Reset()

func (*Information) String

func (m *Information) String() string

func (*Information) XXX_DiscardUnknown

func (m *Information) XXX_DiscardUnknown()

func (*Information) XXX_Marshal

func (m *Information) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Information) XXX_Merge

func (m *Information) XXX_Merge(src proto.Message)

func (*Information) XXX_Size

func (m *Information) XXX_Size() int

func (*Information) XXX_Unmarshal

func (m *Information) XXX_Unmarshal(b []byte) error

type Information_OS

type Information_OS struct {
	Type                 *string  `protobuf:"bytes,1,req,name=type" json:"type,omitempty"`
	Name                 *string  `protobuf:"bytes,2,opt,name=name" json:"name,omitempty"`
	Arch                 *string  `protobuf:"bytes,3,req,name=arch" json:"arch,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*Information_OS) Descriptor

func (*Information_OS) Descriptor() ([]byte, []int)

func (*Information_OS) GetArch

func (m *Information_OS) GetArch() string

func (*Information_OS) GetName

func (m *Information_OS) GetName() string

func (*Information_OS) GetType

func (m *Information_OS) GetType() string

func (*Information_OS) ProtoMessage

func (*Information_OS) ProtoMessage()

func (*Information_OS) Reset

func (m *Information_OS) Reset()

func (*Information_OS) String

func (m *Information_OS) String() string

func (*Information_OS) XXX_DiscardUnknown

func (m *Information_OS) XXX_DiscardUnknown()

func (*Information_OS) XXX_Marshal

func (m *Information_OS) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Information_OS) XXX_Merge

func (m *Information_OS) XXX_Merge(src proto.Message)

func (*Information_OS) XXX_Size

func (m *Information_OS) XXX_Size() int

func (*Information_OS) XXX_Unmarshal

func (m *Information_OS) XXX_Unmarshal(b []byte) error

type Information_User

type Information_User struct {
	Name                 *string  `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
	Group                *string  `protobuf:"bytes,2,opt,name=group" json:"group,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*Information_User) Descriptor

func (*Information_User) Descriptor() ([]byte, []int)

func (*Information_User) GetGroup

func (m *Information_User) GetGroup() string

func (*Information_User) GetName

func (m *Information_User) GetName() string

func (*Information_User) ProtoMessage

func (*Information_User) ProtoMessage()

func (*Information_User) Reset

func (m *Information_User) Reset()

func (*Information_User) String

func (m *Information_User) String() string

func (*Information_User) XXX_DiscardUnknown

func (m *Information_User) XXX_DiscardUnknown()

func (*Information_User) XXX_Marshal

func (m *Information_User) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Information_User) XXX_Merge

func (m *Information_User) XXX_Merge(src proto.Message)

func (*Information_User) XXX_Size

func (m *Information_User) XXX_Size() int

func (*Information_User) XXX_Unmarshal

func (m *Information_User) XXX_Unmarshal(b []byte) error

type Message

type Message struct {
	Type                 *Message_Type `protobuf:"varint,1,req,name=type,enum=agent.Message_Type,def=0" json:"type,omitempty"`
	Payload              []byte        `protobuf:"bytes,2,opt,name=payload" json:"payload,omitempty"`
	XXX_NoUnkeyedLiteral struct{}      `json:"-"`
	XXX_unrecognized     []byte        `json:"-"`
	XXX_sizecache        int32         `json:"-"`
}

Common message protocol

func (*Message) Descriptor

func (*Message) Descriptor() ([]byte, []int)

func (*Message) GetPayload

func (m *Message) GetPayload() []byte

func (*Message) GetType

func (m *Message) GetType() Message_Type

func (*Message) ProtoMessage

func (*Message) ProtoMessage()

func (*Message) Reset

func (m *Message) Reset()

func (*Message) String

func (m *Message) String() string

func (*Message) XXX_DiscardUnknown

func (m *Message) XXX_DiscardUnknown()

func (*Message) XXX_Marshal

func (m *Message) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Message) XXX_Merge

func (m *Message) XXX_Merge(src proto.Message)

func (*Message) XXX_Size

func (m *Message) XXX_Size() int

func (*Message) XXX_Unmarshal

func (m *Message) XXX_Unmarshal(b []byte) error

type Message_Type

type Message_Type int32
const (
	Message_UNKNOWN                 Message_Type = 0
	Message_GET_INFORMATION         Message_Type = 1
	Message_INFORMATION_RESULT      Message_Type = 2
	Message_GET_STATUS_MODULES      Message_Type = 3
	Message_STATUS_MODULES_RESULT   Message_Type = 4
	Message_START_MODULES           Message_Type = 5
	Message_STOP_MODULES            Message_Type = 6
	Message_UPDATE_MODULES          Message_Type = 7
	Message_UPDATE_CONFIG_MODULES   Message_Type = 8
	Message_AUTHENTICATION_REQUEST  Message_Type = 9
	Message_AUTHENTICATION_RESPONSE Message_Type = 10
)
const Default_Message_Type Message_Type = Message_UNKNOWN

func (Message_Type) Enum

func (x Message_Type) Enum() *Message_Type

func (Message_Type) EnumDescriptor

func (Message_Type) EnumDescriptor() ([]byte, []int)

func (Message_Type) String

func (x Message_Type) String() string

func (*Message_Type) UnmarshalJSON

func (x *Message_Type) UnmarshalJSON(data []byte) error

type Module

type Module struct {
	Name                 *string        `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
	Config               *Config        `protobuf:"bytes,2,opt,name=config" json:"config,omitempty"`
	Files                []*Module_File `protobuf:"bytes,3,rep,name=files" json:"files,omitempty"`
	Args                 []*Module_Arg  `protobuf:"bytes,4,rep,name=args" json:"args,omitempty"`
	ConfigItem           *ConfigItem    `protobuf:"bytes,5,opt,name=config_item,json=configItem" json:"config_item,omitempty"`
	XXX_NoUnkeyedLiteral struct{}       `json:"-"`
	XXX_unrecognized     []byte         `json:"-"`
	XXX_sizecache        int32          `json:"-"`
}

Struct of module for loading into agent

func (*Module) Descriptor

func (*Module) Descriptor() ([]byte, []int)

func (*Module) GetArgs

func (m *Module) GetArgs() []*Module_Arg

func (*Module) GetConfig

func (m *Module) GetConfig() *Config

func (*Module) GetConfigItem

func (m *Module) GetConfigItem() *ConfigItem

func (*Module) GetFiles

func (m *Module) GetFiles() []*Module_File

func (*Module) GetName

func (m *Module) GetName() string

func (*Module) ProtoMessage

func (*Module) ProtoMessage()

func (*Module) Reset

func (m *Module) Reset()

func (*Module) String

func (m *Module) String() string

func (*Module) XXX_DiscardUnknown

func (m *Module) XXX_DiscardUnknown()

func (*Module) XXX_Marshal

func (m *Module) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Module) XXX_Merge

func (m *Module) XXX_Merge(src proto.Message)

func (*Module) XXX_Size

func (m *Module) XXX_Size() int

func (*Module) XXX_Unmarshal

func (m *Module) XXX_Unmarshal(b []byte) error

type ModuleList

type ModuleList struct {
	List                 []*Module `protobuf:"bytes,1,rep,name=list" json:"list,omitempty"`
	XXX_NoUnkeyedLiteral struct{}  `json:"-"`
	XXX_unrecognized     []byte    `json:"-"`
	XXX_sizecache        int32     `json:"-"`
}

Communication message for (START_MODULES | STOP_MODULES | UPDATE_MODULES) commands

func (*ModuleList) Descriptor

func (*ModuleList) Descriptor() ([]byte, []int)

func (*ModuleList) GetList

func (m *ModuleList) GetList() []*Module

func (*ModuleList) ProtoMessage

func (*ModuleList) ProtoMessage()

func (*ModuleList) Reset

func (m *ModuleList) Reset()

func (*ModuleList) String

func (m *ModuleList) String() string

func (*ModuleList) XXX_DiscardUnknown

func (m *ModuleList) XXX_DiscardUnknown()

func (*ModuleList) XXX_Marshal

func (m *ModuleList) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ModuleList) XXX_Merge

func (m *ModuleList) XXX_Merge(src proto.Message)

func (*ModuleList) XXX_Size

func (m *ModuleList) XXX_Size() int

func (*ModuleList) XXX_Unmarshal

func (m *ModuleList) XXX_Unmarshal(b []byte) error

type ModuleStatus

type ModuleStatus struct {
	Name                 *string              `protobuf:"bytes,1,req,name=name" json:"name,omitempty"`
	Config               *Config              `protobuf:"bytes,2,req,name=config" json:"config,omitempty"`
	ConfigItem           *ConfigItem          `protobuf:"bytes,3,req,name=config_item,json=configItem" json:"config_item,omitempty"`
	Status               *ModuleStatus_Status `protobuf:"varint,4,req,name=status,enum=agent.ModuleStatus_Status,def=0" json:"status,omitempty"`
	XXX_NoUnkeyedLiteral struct{}             `json:"-"`
	XXX_unrecognized     []byte               `json:"-"`
	XXX_sizecache        int32                `json:"-"`
}

Struct of status module for sending to server

func (*ModuleStatus) Descriptor

func (*ModuleStatus) Descriptor() ([]byte, []int)

func (*ModuleStatus) GetConfig

func (m *ModuleStatus) GetConfig() *Config

func (*ModuleStatus) GetConfigItem

func (m *ModuleStatus) GetConfigItem() *ConfigItem

func (*ModuleStatus) GetName

func (m *ModuleStatus) GetName() string

func (*ModuleStatus) GetStatus

func (m *ModuleStatus) GetStatus() ModuleStatus_Status

func (*ModuleStatus) ProtoMessage

func (*ModuleStatus) ProtoMessage()

func (*ModuleStatus) Reset

func (m *ModuleStatus) Reset()

func (*ModuleStatus) String

func (m *ModuleStatus) String() string

func (*ModuleStatus) XXX_DiscardUnknown

func (m *ModuleStatus) XXX_DiscardUnknown()

func (*ModuleStatus) XXX_Marshal

func (m *ModuleStatus) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ModuleStatus) XXX_Merge

func (m *ModuleStatus) XXX_Merge(src proto.Message)

func (*ModuleStatus) XXX_Size

func (m *ModuleStatus) XXX_Size() int

func (*ModuleStatus) XXX_Unmarshal

func (m *ModuleStatus) XXX_Unmarshal(b []byte) error

type ModuleStatusList

type ModuleStatusList struct {
	List                 []*ModuleStatus `protobuf:"bytes,1,rep,name=list" json:"list,omitempty"`
	XXX_NoUnkeyedLiteral struct{}        `json:"-"`
	XXX_unrecognized     []byte          `json:"-"`
	XXX_sizecache        int32           `json:"-"`
}

Communication message for STATUS_MODULES_RESULT command

func (*ModuleStatusList) Descriptor

func (*ModuleStatusList) Descriptor() ([]byte, []int)

func (*ModuleStatusList) GetList

func (m *ModuleStatusList) GetList() []*ModuleStatus

func (*ModuleStatusList) ProtoMessage

func (*ModuleStatusList) ProtoMessage()

func (*ModuleStatusList) Reset

func (m *ModuleStatusList) Reset()

func (*ModuleStatusList) String

func (m *ModuleStatusList) String() string

func (*ModuleStatusList) XXX_DiscardUnknown

func (m *ModuleStatusList) XXX_DiscardUnknown()

func (*ModuleStatusList) XXX_Marshal

func (m *ModuleStatusList) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ModuleStatusList) XXX_Merge

func (m *ModuleStatusList) XXX_Merge(src proto.Message)

func (*ModuleStatusList) XXX_Size

func (m *ModuleStatusList) XXX_Size() int

func (*ModuleStatusList) XXX_Unmarshal

func (m *ModuleStatusList) XXX_Unmarshal(b []byte) error

type ModuleStatus_Status

type ModuleStatus_Status int32
const (
	ModuleStatus_UNKNOWN ModuleStatus_Status = 0
	ModuleStatus_LOADED  ModuleStatus_Status = 1
	ModuleStatus_RUNNING ModuleStatus_Status = 2
	ModuleStatus_STOPPED ModuleStatus_Status = 3
	ModuleStatus_FREED   ModuleStatus_Status = 4
)
const Default_ModuleStatus_Status ModuleStatus_Status = ModuleStatus_UNKNOWN

func (ModuleStatus_Status) Enum

func (ModuleStatus_Status) EnumDescriptor

func (ModuleStatus_Status) EnumDescriptor() ([]byte, []int)

func (ModuleStatus_Status) String

func (x ModuleStatus_Status) String() string

func (*ModuleStatus_Status) UnmarshalJSON

func (x *ModuleStatus_Status) UnmarshalJSON(data []byte) error

type Module_Arg

type Module_Arg struct {
	Key                  *string  `protobuf:"bytes,1,req,name=key" json:"key,omitempty"`
	Value                []string `protobuf:"bytes,2,rep,name=value" json:"value,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*Module_Arg) Descriptor

func (*Module_Arg) Descriptor() ([]byte, []int)

func (*Module_Arg) GetKey

func (m *Module_Arg) GetKey() string

func (*Module_Arg) GetValue

func (m *Module_Arg) GetValue() []string

func (*Module_Arg) ProtoMessage

func (*Module_Arg) ProtoMessage()

func (*Module_Arg) Reset

func (m *Module_Arg) Reset()

func (*Module_Arg) String

func (m *Module_Arg) String() string

func (*Module_Arg) XXX_DiscardUnknown

func (m *Module_Arg) XXX_DiscardUnknown()

func (*Module_Arg) XXX_Marshal

func (m *Module_Arg) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Module_Arg) XXX_Merge

func (m *Module_Arg) XXX_Merge(src proto.Message)

func (*Module_Arg) XXX_Size

func (m *Module_Arg) XXX_Size() int

func (*Module_Arg) XXX_Unmarshal

func (m *Module_Arg) XXX_Unmarshal(b []byte) error

type Module_File

type Module_File struct {
	Path                 *string  `protobuf:"bytes,1,opt,name=path" json:"path,omitempty"`
	Data                 []byte   `protobuf:"bytes,2,req,name=data" json:"data,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*Module_File) Descriptor

func (*Module_File) Descriptor() ([]byte, []int)

func (*Module_File) GetData

func (m *Module_File) GetData() []byte

func (*Module_File) GetPath

func (m *Module_File) GetPath() string

func (*Module_File) ProtoMessage

func (*Module_File) ProtoMessage()

func (*Module_File) Reset

func (m *Module_File) Reset()

func (*Module_File) String

func (m *Module_File) String() string

func (*Module_File) XXX_DiscardUnknown

func (m *Module_File) XXX_DiscardUnknown()

func (*Module_File) XXX_Marshal

func (m *Module_File) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Module_File) XXX_Merge

func (m *Module_File) XXX_Merge(src proto.Message)

func (*Module_File) XXX_Size

func (m *Module_File) XXX_Size() int

func (*Module_File) XXX_Unmarshal

func (m *Module_File) XXX_Unmarshal(b []byte) error

Jump to