utils

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 30, 2021 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DoHandshakeWithAgentOnServer

func DoHandshakeWithAgentOnServer(socket vxproto.IAgentSocket) error

DoHandshakeWithAgentOnServer is function which implemented server logic of handshake

func DoHandshakeWithBrowserOnServer

func DoHandshakeWithBrowserOnServer(socket vxproto.IAgentSocket) error

DoHandshakeWithBrowserOnServer is function which implemented server logic of handshake

func DoHandshakeWithServerOnAgent

func DoHandshakeWithServerOnAgent(socket vxproto.IAgentSocket) error

DoHandshakeWithServerOnAgent is function which implemented agent logic of handshake

func DoHandshakeWithServerOnBrowser

func DoHandshakeWithServerOnBrowser(socket vxproto.IAgentSocket) error

DoHandshakeWithServerOnBrowser is function which implemented agent logic of handshake It implemented for testing only

func GetAgentInformation

func GetAgentInformation() *agent.Information

GetAgentInformation is additional function for handshake logic

func GetRef

func GetRef(str string) *string

GetRef is function for returning referense of string

func HasInfoValid

func HasInfoValid(info *agent.Information) bool

HasInfoValid is function which validate information from agent

func InList

func InList(list []string, str string) bool

InList is function for searching in array of string

func RemoveUnusedTempDir

func RemoveUnusedTempDir()

RemoveUnusedTempDir is public function that should use into worker on start

Types

This section is empty.

Jump to