Documentation
¶
Index ¶
- func DoHandshakeWithAgentOnServer(socket vxproto.IAgentSocket) error
- func DoHandshakeWithBrowserOnServer(socket vxproto.IAgentSocket) error
- func DoHandshakeWithServerOnAgent(socket vxproto.IAgentSocket) error
- func DoHandshakeWithServerOnBrowser(socket vxproto.IAgentSocket) error
- func GetAgentInformation() *agent.Information
- func GetRef(str string) *string
- func HasInfoValid(info *agent.Information) bool
- func InList(list []string, str string) bool
- func RemoveUnusedTempDir()
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DoHandshakeWithAgentOnServer ¶
func DoHandshakeWithAgentOnServer(socket vxproto.IAgentSocket) error
DoHandshakeWithAgentOnServer is function which implemented server logic of handshake
func DoHandshakeWithBrowserOnServer ¶
func DoHandshakeWithBrowserOnServer(socket vxproto.IAgentSocket) error
DoHandshakeWithBrowserOnServer is function which implemented server logic of handshake
func DoHandshakeWithServerOnAgent ¶
func DoHandshakeWithServerOnAgent(socket vxproto.IAgentSocket) error
DoHandshakeWithServerOnAgent is function which implemented agent logic of handshake
func DoHandshakeWithServerOnBrowser ¶
func DoHandshakeWithServerOnBrowser(socket vxproto.IAgentSocket) error
DoHandshakeWithServerOnBrowser is function which implemented agent logic of handshake It implemented for testing only
func GetAgentInformation ¶
func GetAgentInformation() *agent.Information
GetAgentInformation is additional function for handshake logic
func HasInfoValid ¶
func HasInfoValid(info *agent.Information) bool
HasInfoValid is function which validate information from agent
func RemoveUnusedTempDir ¶
func RemoveUnusedTempDir()
RemoveUnusedTempDir is public function that should use into worker on start
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.